@@ -2,7 +2,7 @@
 """Main Controller"""
 
 from tg import TGController
-from tg import expose, flash, require, url, lurl, request, redirect, validate, abort
+from tg import expose, flash, require, url, lurl, request, redirect, validate, abort, config
 from tg.i18n import ugettext as _, lazy_ugettext as l_
 from tg.decorators import cached_property
 
@@ -92,7 +92,8 @@ class RootController(TGController):
     @expose('genshi:photos.templates.gallery')
     @validate(dict(gallery=SQLAEntityConverter(Gallery)), error_handler=index)
     def gallery(self, gallery):
-        return dict(gallery=gallery)
+        photos_config = config.get('_pluggable_photos_config')
+        return dict(gallery=gallery, inline=photos_config.get('inline_photos', True))
 
     @expose('genshi:photos.templates.photo')
     @validate(dict(photo=SQLAEntityConverter(Photo)), error_handler=lambda c:abort(404))
